rayoptics package
=================

Subpackages
-----------

.. toctree::

    rayoptics.codev
    rayoptics.gui
    rayoptics.mpl
    rayoptics.optical
    rayoptics.qtgui
    rayoptics.util

Submodules
----------

rayoptics.environment module
----------------------------

.. automodule:: rayoptics.environment
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: rayoptics
    :members:
    :undoc-members:
    :show-inheritance:
